collections library

Classes

MonitoredList<T, E>
A List<E> that is monitored for internal changes which then notify the data model within which it is declared.
MonitoredMap<T, K, V>
A Map<K, V> that is monitored for internal changes which then notify the data model within which it is declared.
MonitoredSet<T, E>
A Set<E> that is monitored for internal changes which then notify the data model within which it is declared.