DataItem class

DataItem is used to track a field in a data model for changes.

When a change is detected, all associated DataProperty elements are marked as dirty.

Constructors

DataItem(dynamic value, List<DataProperty> properties)

Properties

hashCode int
The hash code for this object.
no setterinherited
properties List<DataProperty>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(dynamic newValue) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited