data_monitor library

Classes

CacheAnnotation
CacheAnnotation provides the @cache annotation for use in your data model classes.
DataItem
DataItem is used to track a field in a data model for changes.
DataMonitorAnnotation
DataMonitorAnnotation provides the @dataMonitor annotation for use in your data model classes.
DataNotifier
A class that will notify listeners to changes AFTER calling the passed notify function (if one is provided).
DataProperty
A DataProperty can be marked as dirty by an associated DataItem
MonitorAnnotation
MonitorAnnotation provides the @monitor annotation for use in your data model classes.
MonitoredList<E>
A List<E> that is monitored for internal changes which then notify the data model with which it was instantiated.
MonitoredMap<K, V>
A Map<K, V> that is monitored for internal changes which then notify the data model with which it was instantiated.
MonitoredSet<E>
A Set<E> that is monitored for internal changes which then notify the data model with which it was instantiated.
PropagateAnnotation
PropagateAnnotation provides the @propagate annotation for use in your data model classes.