DataProperty class
A DataProperty can be marked as dirty by an associated DataItem
When it is dirty, its cached value is no longer used. Instead, it is recalculated the next time its value is read (via its getter).
Constructors
- DataProperty(dynamic value)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
dynamic newValue) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited